pub enum PieceSource {
Boundary(EdgeId),
Section(usize),
Collapsed,
}Expand description
Where a piece of a split face’s boundary came from.
Variants
Boundary(EdgeId)
Part of one of the face’s own edges.
Section(usize)
Part of the section edge with this index in the list given.
Collapsed
A stretch of parameters that is one point in space – a sphere’s pole, a cone’s apex – closing a loop in the face’s parameters. It bounds regions while the face is split but is no edge of the result.