Function section_edges

pub fn section_edges(
    a: &ExactBRep,
    b: &ExactBRep,
    tolerance: Tolerance,
) -> Result<Vec<SectionEdge>, BooleanError>
Every section edge between the faces of a and the faces of b.

Errors

A face pair whose section is not a line, circle or ellipse, or a piece too close to a face boundary to classify.